==> gcc-3.4.3.tar.gz: gcc-3.4.3/libstdc++-v3/testsuite/22_locale/num_get/get/wchar_t/9.cc <==
// 2003-12-19  Paolo Carlini  <pcarlini@suse.de>

// Copyright (C) 2003 Free Software Foundation
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// 22.2.2.1.1  num_get members

#include <locale>
#include <sstream>
#include <testsuite_hooks.h>

void test01()
{
  using namespace std;
  typedef istreambuf_iterator<wchar_t> iterator_type;
  
  bool test __attribute__((unused)) = true;

  // A locale that expects grouping  
  locale loc_de = __gnu_test::try_named_locale("de_DE");
  wistringstream iss;
  iss.imbue(loc_de);

  const num_get<wchar_t>& ng = use_facet<num_get<wchar_t> >(iss.getloc()); 
  ios_base::iostate err = ios_base::goodbit;
  iterator_type end;
  double d = 0.0;
  double d1 = 1e1;
  double d2 = 3e1;
  
  iss.str(L"1e1,");
  end = ng.get(iss.rdbuf(), 0, iss, err, d);
  VERIFY( err == ios_base::goodbit );
  VERIFY( *end == L',' );
  VERIFY( d == d1 );

  iss.str(L"3e1.");
  iss.clear();
  err = ios_base::goodbit;
  end = ng.get(iss.rdbuf(), 0, iss, err, d);
  VERIFY( err == ios_base::goodbit );
  VERIFY( *end == L'.' );
  VERIFY( d == d2 );
}

int main()
{
  test01();
  return 0;
}

==> gcc-4.9-4.9.2.tar.gz: gcc-4.9.2/libstdc++-v3/testsuite/22_locale/num_get/get/wchar_t/9.cc <==
// { dg-require-namedlocale "de_DE" }

// 2003-12-19  Paolo Carlini  <pcarlini@suse.de>

// Copyright (C) 2003-2014 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

// 22.2.2.1.1  num_get members

#include <locale>
#include <sstream>
#include <testsuite_hooks.h>

void test01()
{
  using namespace std;
  typedef istreambuf_iterator<wchar_t> iterator_type;
  
  bool test __attribute__((unused)) = true;

  // A locale that expects grouping  
  locale loc_de = locale("de_DE");
  wistringstream iss;
  iss.imbue(loc_de);

  const num_get<wchar_t>& ng = use_facet<num_get<wchar_t> >(iss.getloc()); 
  ios_base::iostate err = ios_base::goodbit;
  iterator_type end;
  double d = 0.0;
  double d1 = 1e1;
  double d2 = 3e1;
  
  iss.str(L"1e1,");
  end = ng.get(iss.rdbuf(), 0, iss, err, d);
  VERIFY( err == ios_base::goodbit );
  VERIFY( *end == L',' );
  VERIFY( d == d1 );

  iss.str(L"3e1.");
  iss.clear();
  err = ios_base::goodbit;
  end = ng.get(iss.rdbuf(), 0, iss, err, d);
  VERIFY( err == ios_base::goodbit );
  VERIFY( *end == L'.' );
  VERIFY( d == d2 );
}

int main()
{
  test01();
  return 0;
}
